@@ -1,7 +1,9 @@
 from enum import Enum
-from typing import Sequence, Union
+from typing import Sequence, Union, Tuple, List
+
 import numpy as np
-from deep_utils.utils.logging_utils.logging_utils import log_print, value_error_log
+
+from deep_utils.utils.logging_utils.logging_utils import value_error_log
 
 
 class Point:
@@ -209,6 +211,24 @@ class Point:
         down_right = max(pts, key=lambda l: l[1])
         return top_left, top_right, down_right, down_left
 
+    @staticmethod
+    def rotate_point(target_p: tuple[int, int], center_p: tuple[int, int], degree: float):
+        """
+        :param target_p:
+        :param center_p:
+        :param degree:
+        :return:
+        """
+        degree = - degree  # to make it aligned with cv2 rotation direction
+        rad = degree * np.pi / 180
+        t_x, t_y = target_p
+        c_x, c_y = center_p
+        delta_x = (t_x - c_x)
+        delta_y = (t_y - c_y)
+        x = np.cos(rad) * delta_x - np.sin(rad) * delta_y + c_x
+        y = np.sin(rad) * delta_x + np.cos(rad) * delta_y + c_y
+        return int(x), int(y)
+
 
 class Box:
     class BoxFormat(Enum):
@@ -227,6 +247,62 @@ class Box:
         List = list
         Tuple = tuple
 
+    PointSource = Point.PointSource
+
+    @staticmethod
+    def check_overlap(box_a: Union[Tuple[int, int, int, int], List[int]],
+                      box_b: Union[Tuple[int, int, int, int], List[int]]):
+        """
+        Check if two boxes overlap
+        :param box_a:
+        :param box_b:
+        :return:
+        """
+        p1_x1, p1_y1, p1_x2, p1_y2 = box_a
+        p2_x1, p2_y1, p2_x2, p2_y2 = box_b
+
+        if p1_x1 > p2_x2 or p1_x2 < p2_x1:
+            return False
+        if p1_y1 > p2_y2 or p1_y2 < p2_y1:
+            return False
+        return True
+
+    @staticmethod
+    def resize_box(box: List[int],
+                   img_input_shape: Union[list, tuple] = None,
+                   img_resized_shape: Union[list, tuple] = None,
+                   return_int: bool = True):
+        """
+        Resize a box from one source to another when the image is resized. Box and shapes must be in Numpy source.
+        Box must be in XYXY format.
+        :param box:
+        :param img_input_shape:
+        :param img_resized_shape:
+        :param return_int: if True, return the box as int, else return as float
+        :return:
+        """
+        if box is None or len(box) == 0:
+            raise ValueError("box is None or empty")
+        if len(box) != 4:
+            raise ValueError(f"box must have 4 elements, got {len(box)}")
+        # get the ratio
+        if img_input_shape is None or img_resized_shape is None:
+            raise ValueError("img_input_shape and img_resized_shape must be provided")
+        if len(img_input_shape) != 2 or len(img_resized_shape) != 2:
+            raise ValueError("img_input_shape and img_resized_shape must be 2D")
+        ratio_w = img_resized_shape[0] / img_input_shape[0]
+        ratio_h = img_resized_shape[1] / img_input_shape[1]
+        # resize the box
+        resized_box = [
+            box[0] * ratio_w,
+            box[1] * ratio_h,
+            box[2] * ratio_w,
+            box[3] * ratio_h,
+        ]
+        if return_int:
+            resized_box = [round(b) for b in resized_box]
+        return resized_box
+
     @staticmethod
     def box2box(
             box,
