@@ -23,10 +23,10 @@ if platform.system() != 'Windows':
 
 from models.common import *
 from models.experimental import *
-from utils_.autoanchor import check_anchor_order
-from utils_.general import LOGGER, check_version, check_yaml, make_divisible, print_args
-from utils_.plots import feature_visualization
-from utils_.torch_utils import (fuse_conv_and_bn, initialize_weights, model_info, profile, scale_img, select_device,
+from yolov5_utils.autoanchor import check_anchor_order
+from yolov5_utils.general import LOGGER, check_version, check_yaml, make_divisible, print_args
+from yolov5_utils.plots import feature_visualization
+from yolov5_utils.torch_utils import (fuse_conv_and_bn, initialize_weights, model_info, profile, scale_img, select_device,
                                time_sync)
 
 try:
