@@ -1,44 +1,21 @@
-import os
-import shutil
 import sys
 import time
-from os.path import join
 from pathlib import Path
 from typing import Dict, List, Type, Union
 
 import numpy as np
 import torch
-from tqdm import tqdm
 
 from deep_utils.utils.box_utils.boxes import Box
 from deep_utils.utils.dict_named_tuple_utils import dictnamedtuple
-from deep_utils.utils.dir_utils.dir_utils import (
-    dir_train_test_split,
-    remove_create,
-    transfer_directory_items,
-    file_incremental,
-)
 from deep_utils.utils.lib_utils.lib_decorators import (
-    get_from_config,
     in_shape_fix,
     lib_rgb2bgr,
     out_shape_fix,
 )
-from deep_utils.utils.logging_utils import log_print
-from deep_utils.utils.opencv_utils.main import show_destroy_cv2
-from deep_utils.utils.os_utils.os_path import split_extension
-from deep_utils.utils.shutil_utils.shutil_utils import mv_or_copy
 from deep_utils.vision.object_detection.yolo.yolo_detector import YOLOObjectDetector
 from .config import Config
 
-FILE = Path(__file__).resolve()
-ROOT = FILE.parents[0]  # YOLOv5 root directory
-if str(ROOT) not in sys.path:
-    sys.path.append(str(ROOT))  # add ROOT to PATH
-from .models.experimental import attempt_load
-from .utils_.datasets import letterbox
-from .utils_.general import non_max_suppression, scale_boxes
-
 OUTPUT_CLASS = dictnamedtuple(
     "Object", ["class_indices", "boxes", "confidences", "class_names", "elapsed_time"]
 )
@@ -85,7 +62,7 @@ class YOLOV5TorchObjectDetector(YOLOObjectDetector):
             scaleFill=False,
             scaleup=True,
     ):
-
+        from .yolov5_utils.datasets import letterbox
         return letterbox(
             img,
             new_shape=new_shape,
@@ -96,7 +73,14 @@ class YOLOV5TorchObjectDetector(YOLOObjectDetector):
         )
 
     def load_model(self):
-        # if self.config.model_weight:
+        FILE = Path(__file__).resolve()
+        ROOT = str(FILE.parents[0])  # YOLOv5 root directory
+        if ROOT not in sys.path:
+            sys.path.append(ROOT)  # add ROOT to PATH
+            v7_root = ROOT.replace("v5", "v7")
+            if v7_root in sys.path:
+                sys.path.remove(v7_root)
+        from .models.experimental import attempt_load
         self.model = attempt_load(
             self.config.model_weight, device=self.config.device
         )
@@ -116,6 +100,8 @@ class YOLOV5TorchObjectDetector(YOLOObjectDetector):
             img_size=None,
             agnostic=None,
             get_time=False,
+            logger=None,
+            verbose=1
     ) -> Union[Type[OutputType], Dict[str, list]]:
         """
 
@@ -127,10 +113,11 @@ class YOLOV5TorchObjectDetector(YOLOObjectDetector):
         :param agnostic:
         :param get_time:
         :param img_size:
-        :param kwargs:
+        :param logger:
+        :param verbose:
         :return:
         """
-
+        from .yolov5_utils.general import non_max_suppression, scale_boxes
         tic = time.time() if get_time else 0
 
         self.update_config(
@@ -191,4 +178,4 @@ class YOLOV5TorchObjectDetector(YOLOObjectDetector):
             elapsed_time=elapsed_time,
         )
         output = out_shape_fix(output)
-        return output
\ No newline at end of file
+        return output
