@@ -1,10 +1,12 @@
 import logging
 
 
-def get_logger(name='root'):
+def get_logger(name="root"):
     formatter = logging.Formatter(
         # fmt='%(asctime)s [%(levelname)s]: %(filename)s(%(funcName)s:%(lineno)s) >> %(message)s')
-        fmt='%(asctime)s [%(levelname)s]: %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
+        fmt="%(asctime)s [%(levelname)s]: %(message)s",
+        datefmt="%Y-%m-%d %H:%M:%S",
+    )
 
     handler = logging.StreamHandler()
     handler.setFormatter(formatter)
@@ -13,5 +15,3 @@ def get_logger(name='root'):
     logger.setLevel(logging.INFO)
     logger.addHandler(handler)
     return logger
-
-
